summaryrefslogtreecommitdiff
path: root/cups/cups-private.h
diff options
context:
space:
mode:
authormsweet <msweet@a1ca3aef-8c08-0410-bb20-df032aa958be>2014-05-07 23:55:35 +0000
committermsweet <msweet@a1ca3aef-8c08-0410-bb20-df032aa958be>2014-05-07 23:55:35 +0000
commitf51f3773d1c141dfeffcb6ef478129197dde3a96 (patch)
tree69f3947fe49d7a890b13461ff307d8e47feaf803 /cups/cups-private.h
parent524c65e662f2c36fd6a5321425a30d2cdd2d4ece (diff)
downloadcups-f51f3773d1c141dfeffcb6ef478129197dde3a96.tar.gz
Add code to validate trust when printing via the IPP backend.
Add new CUPS_VALIDATECERTS (ValidateCerts in the conf file) setting to control whether we require the common name to match the host name, default is no. (currently) httpCredentialsGetTrust now only checks hostname/common name matches when validation is enabled. Otherwise we just look for changes to certs. git-svn-id: svn+ssh://src.apple.com/svn/cups/cups.org/trunk@11851 a1ca3aef-8c08-0410-bb20-df032aa958be
Diffstat (limited to 'cups/cups-private.h')
-rw-r--r--cups/cups-private.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/cups/cups-private.h b/cups/cups-private.h
index f4c075c56..8e2d69295 100644
--- a/cups/cups-private.h
+++ b/cups/cups-private.h
@@ -167,7 +167,8 @@ typedef struct _cups_globals_s /**** CUPS global state data ****/
/* Server certificate user data */
int server_version, /* Server IPP version */
any_root, /* Allow any (e.g., self-signed) root */
- expired_certs; /* Allow expired certs */
+ expired_certs, /* Allow expired certs */
+ validate_certs; /* Validate certificates */
/* util.c */
char def_printer[256];